
#line 3 "lex.cmatrix.c"

#define  YY_INT_ALIGNED short

/* A lexical scanner generated by flex */

#define yy_create_buffer cmatrix_create_buffer
#define yy_delete_buffer cmatrix_delete_buffer
#define yy_flex_debug cmatrix_flex_debug
#define yy_init_buffer cmatrix_init_buffer
#define yy_flush_buffer cmatrix_flush_buffer
#define yy_load_buffer_state cmatrix_load_buffer_state
#define yy_switch_to_buffer cmatrix_switch_to_buffer
#define yyin cmatrixin
#define yyleng cmatrixleng
#define yylex cmatrixlex
#define yylineno cmatrixlineno
#define yyout cmatrixout
#define yyrestart cmatrixrestart
#define yytext cmatrixtext
#define yywrap cmatrixwrap
#define yyalloc cmatrixalloc
#define yyrealloc cmatrixrealloc
#define yyfree cmatrixfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types.
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t;
typedef unsigned short flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE cmatrixrestart(cmatrixin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int cmatrixleng;

extern FILE *cmatrixin, *cmatrixout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up cmatrixtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up cmatrixtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via cmatrixrestart()), so that the user can continue scanning by
	 * just pointing cmatrixin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when cmatrixtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int cmatrixleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow cmatrixwrap()'s to do buffer switches
 * instead of setting up a fresh cmatrixin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void cmatrixrestart (FILE *input_file  );
void cmatrix_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE cmatrix_create_buffer (FILE *file,int size  );
void cmatrix_delete_buffer (YY_BUFFER_STATE b  );
void cmatrix_flush_buffer (YY_BUFFER_STATE b  );
void cmatrixpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void cmatrixpop_buffer_state (void );

static void cmatrixensure_buffer_stack (void );
static void cmatrix_load_buffer_state (void );
static void cmatrix_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER cmatrix_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE cmatrix_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE cmatrix_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE cmatrix_scan_bytes (yyconst char *bytes,int len  );

void *cmatrixalloc (yy_size_t  );
void *cmatrixrealloc (void *,yy_size_t  );
void cmatrixfree (void *  );

#define yy_new_buffer cmatrix_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        cmatrixensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            cmatrix_create_buffer(cmatrixin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        cmatrixensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            cmatrix_create_buffer(cmatrixin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define cmatrixwrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *cmatrixin = (FILE *) 0, *cmatrixout = (FILE *) 0;

typedef int yy_state_type;

extern int cmatrixlineno;

int cmatrixlineno = 1;

extern char *cmatrixtext;
#define yytext_ptr cmatrixtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up cmatrixtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	cmatrixleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 15
#define YY_END_OF_BUFFER 16
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[70] =
    {   0,
       16,   15,   15,   14,   15,   15,   15,   15,   15,   15,
       14,   15,   15,   15,   15,    5,   15,   10,   15,   11,
       15,   12,   15,   13,   15,    9,   15,    9,   14,   15,
       15,   15,   15,    7,16392,    6,    5,    5,    5,    7,
    16392,    5,    5,    5,   10,   11,   12,   13,    9, 8200,
        5, 8200,    5,    5,    5,    5,    5,    5,    5,    5,
    16388,    5, 8196,16386,16387, 8194, 8195,16385, 8193
    } ;

static yyconst flex_int16_t yy_accept[117] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    3,    4,    6,    7,    8,    9,
       10,   11,   13,   14,   15,   16,   18,   20,   22,   24,
       26,   28,   31,   32,   33,   34,   34,   36,   36,   36,
       36,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   38,   39,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   50,   50,   50,   50,   50,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   53,   54,
       55,   56,   57,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   59,   60,   61,   61,   62,   62,   62,   62,

       63,   64,   64,   64,   64,   65,   66,   66,   67,   68,
       68,   68,   68,   69,   70,   70
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    1,    6,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    8,    1,    1,
        1,    1,    1,    1,    1,    1,    9,   10,    1,    1,
        1,    1,   11,    1,    1,    1,    1,    1,    1,    1,
        1,    1,   12,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,   13,    1,    1,

       14,    1,    1,    1,   15,    1,    1,   16,    1,   17,
       18,    1,    1,   19,   20,   21,   22,    1,    1,    1,
        1,    1,    1,   23,    1,    1,    1,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   25,   25,   25,   25,   25,   25,   25,   25,   25,

       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   26,   26,   27,
       27,   27,   27,   27,   27,   27,   27,   24,   24,   24,
       24,   24,   24,   24,   24
    } ;

static yyconst flex_int32_t yy_meta[28] =
    {   0,
        1,    2,    3,    2,    2,    1,    1,    4,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[143] =
    {   0,
        0,  192,   25,   26,   31,   32,   37,   38,   59,   60,
       82,  108,  197,   43,  678,  678,   31,  128,   32,   35,
       53,  178,   72,    0,    0,  154,  188,  187,  186,  185,
       53,   66,  180,    0,    0,  172,   72,   98,    0,    0,
       92,  203,    0,    0,  103,  108,  107,   76,  136,    0,
      226,    0,  252,    0,    0,    0,  169,  150,  143,  113,
      103,  278,    0,    0,  301,    0,  117,  324,    0,    0,
      347,    0,   83,  131,  133,  119,  159,  370,    0,    0,
        0,    0,    0,  396,  419,    0,  442,  465,  147,   54,
      148,    0,    0,    0,  482,  505,  134,  149,  156,    0,

      108,  511,  528,  154,  545,  551,  155,  107,   88,  168,
      173,  557,  574,   81,  678,  581,  585,  589,   80,  593,
      597,  601,   58,  605,  609,   46,  613,  617,  621,  625,
      629,  633,  637,  641,  645,  649,  653,  657,  661,  665,
      669,  673
    } ;

static yyconst flex_int16_t yy_def[143] =
    {   0,
      115,    1,  116,  116,  116,  116,  116,  116,  116,  116,
      117,  117,  115,  118,  115,  115,  119,  118,   18,   18,
       18,   18,  118,  120,  121,  122,  115,  115,  115,  115,
      123,  123,  123,  124,  125,   18,  126,  118,  120,  121,
      119,  119,  127,  128,   18,   18,   18,   18,  118,  129,
      122,  130,  131,  122,  132,  133,  115,  115,  115,  115,
      123,  123,  124,  125,  123,  134,  126,  126,  135,  136,
      119,  137,   18,   18,   18,   18,  118,  131,  131,  138,
      139,  122,  140,  123,  126,  141,  119,   18,   18,   18,
       18,  131,  142,  122,  126,  115,   18,   18,   18,  131,

      115,   18,   18,   18,  115,  115,   18,  115,  115,   18,
       18,   18,  115,  115,    0,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115
    } ;

static yyconst flex_int16_t yy_nxt[706] =
    {   0,
       14,   15,   16,   15,   16,   14,   14,   17,   18,   19,
       20,   21,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   22,   15,   23,   24,   25,   16,   16,   16,
       16,   27,   27,   16,   16,   16,   16,   28,   28,   16,
       16,   16,   16,   29,   29,   46,   67,   16,   16,   36,
       37,   47,   36,   16,   16,   42,   43,   44,   61,   16,
       16,   16,   16,   16,   16,   30,   30,   38,   39,   40,
       36,   36,   98,   36,   48,   36,   36,   62,   63,   64,
       41,   16,   16,   15,   16,   15,   16,  114,   76,   15,
       62,   63,   64,   36,  109,   36,   68,   69,   70,   36,

       36,   36,   36,   88,   32,   15,   33,   34,   35,   15,
       16,   15,   16,  108,  101,   15,   42,   43,   44,   60,
       36,   36,   73,   74,   36,   36,   75,   62,   63,   64,
       32,   15,   33,   34,   35,   37,   36,   36,   91,   36,
       36,   68,   69,   70,   89,   45,   90,  102,   36,   59,
       36,   36,   38,   39,   40,   52,   58,   52,   52,   36,
       36,   53,   36,   36,   36,   36,   36,   97,   99,  103,
      104,   36,   36,   36,  107,   57,  110,   52,   54,   55,
       56,   61,   36,   61,   61,   36,  112,   61,  111,   36,
       36,   60,   59,   58,   57,   36,  115,   26,  115,  115,

      115,  115,  115,   61,   41,  115,   41,   41,  115,  115,
       41,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,   41,   52,  115,   52,
       52,  115,  115,   53,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,   52,
       54,   55,   56,   52,  115,   52,   52,  115,  115,   52,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,   52,   79,   80,   81,   61,
      115,   61,   61,  115,  115,   61,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,

      115,   61,   61,  115,   61,   61,  115,  115,   61,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,   61,   67,  115,   67,   67,  115,
      115,   67,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,   67,   41,  115,
       41,   41,  115,  115,   41,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
       41,   52,  115,   52,   52,  115,  115,   52,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,   52,   79,   80,   81,   61,  115,   61,

       61,  115,  115,   61,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,   61,
       67,  115,   67,   67,  115,  115,   67,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,   67,   41,  115,   41,   41,  115,  115,   41,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,   41,   96,   96,   96,   96,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,   36,   67,  115,   67,   67,  115,  115,   67,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115,   67,   96,   96,   96,   96,
      115,  101,  105,  105,  105,  105,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,   36,  106,
      106,  106,  106,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,   36,  105,  105,  105,  105,
      115,  108,  106,  106,  106,  106,  115,  109,  113,  113,
      113,  113,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,   36,  113,  113,  113,  113,  115,
      114,   15,   15,   15,   15,   31,   31,   31,   31,   36,
      115,  115,   36,   49,   49,  115,   49,   50,   50,  115,

       50,   51,   51,  115,   51,   65,   65,  115,   65,   66,
       66,  115,   66,   71,   71,  115,   71,   72,   72,  115,
       72,   77,   77,  115,   77,   52,   52,  115,   52,   78,
       78,  115,   78,   82,   82,  115,   82,   83,   83,  115,
       83,   84,   84,  115,   84,   85,   85,  115,   85,   86,
       86,  115,   86,   87,   87,  115,   87,   92,   92,  115,
       92,   93,   93,  115,   93,   94,   94,  115,   94,   95,
       95,  115,   95,  100,  100,  115,  100,   13,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115
    } ;

static yyconst flex_int16_t yy_chk[706] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    3,    4,    3,
        4,    3,    4,    5,    6,    5,    6,    5,    6,    7,
        8,    7,    8,    7,    8,   19,  126,    3,    4,   19,
       14,   20,   20,    5,    6,   17,   17,   17,  123,    7,
        8,    9,   10,    9,   10,    9,   10,   14,   14,   14,
       21,   90,   90,   23,   21,   23,   23,   31,   31,   31,
      119,    9,   10,   11,   11,   11,   11,  114,   48,   11,
       32,   32,   32,   48,  109,   23,   37,   37,   37,   38,

       73,   38,   38,   73,   11,   11,   11,   11,   11,   12,
       12,   12,   12,  108,  101,   12,   41,   41,   41,   60,
       45,   38,   45,   46,   47,   46,   47,   61,   61,   61,
       12,   12,   12,   12,   12,   18,   76,   49,   76,   49,
       49,   67,   67,   67,   74,   18,   75,   97,   74,   59,
       75,   97,   18,   18,   18,   26,   58,   26,   26,   49,
       77,   26,   77,   77,   89,   91,   98,   89,   91,   98,
       99,  104,  107,   99,  104,   57,  107,   26,   26,   26,
       26,   33,   77,   33,   33,  110,  111,   33,  110,   36,
      111,   30,   29,   28,   27,   22,   13,    2,    0,    0,

        0,    0,    0,   33,   42,    0,   42,   42,    0,    0,
       42,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   42,   51,    0,   51,
       51,    0,    0,   51,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   51,
       51,   51,   51,   53,    0,   53,   53,    0,    0,   53,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   53,   53,   53,   53,   62,
        0,   62,   62,    0,    0,   62,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,   62,   65,    0,   65,   65,    0,    0,   65,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   65,   68,    0,   68,   68,    0,
        0,   68,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   68,   71,    0,
       71,   71,    0,    0,   71,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       71,   78,    0,   78,   78,    0,    0,   78,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   78,   78,   78,   78,   84,    0,   84,

       84,    0,    0,   84,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   84,
       85,    0,   85,   85,    0,    0,   85,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   85,   87,    0,   87,   87,    0,    0,   87,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   87,   88,   88,   88,   88,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   88,   95,    0,   95,   95,    0,    0,   95,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,   95,   96,   96,   96,   96,
        0,   96,  102,  102,  102,  102,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  102,  103,
      103,  103,  103,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  103,  105,  105,  105,  105,
        0,  105,  106,  106,  106,  106,    0,  106,  112,  112,
      112,  112,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  112,  113,  113,  113,  113,    0,
      113,  116,  116,  116,  116,  117,  117,  117,  117,  118,
        0,    0,  118,  120,  120,    0,  120,  121,  121,    0,

      121,  122,  122,    0,  122,  124,  124,    0,  124,  125,
      125,    0,  125,  127,  127,    0,  127,  128,  128,    0,
      128,  129,  129,    0,  129,  130,  130,    0,  130,  131,
      131,    0,  131,  132,  132,    0,  132,  133,  133,    0,
      133,  134,  134,    0,  134,  135,  135,    0,  135,  136,
      136,    0,  136,  137,  137,    0,  137,  138,  138,    0,
      138,  139,  139,    0,  139,  140,  140,    0,  140,  141,
      141,    0,  141,  142,  142,    0,  142,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115
    } ;

extern int cmatrix_flex_debug;
int cmatrix_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up cmatrixtext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *cmatrixtext;
#line 1 "cmatrix.l"
/*     Foma: a finite-state toolkit and library.                             */
/*     Copyright © 2008-2009 Mans Hulden                                     */
/*     This file is part of foma.                                            */
/*     Foma is free software: you can redistribute it and/or modify          */
/*     it under the terms of the GNU General Public License version 2 as     */
/*     published by the Free Software Foundation. */
/*     Foma is distributed in the hope that it will be useful,               */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of        */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
/*     GNU General Public License for more details.                          */
/*     You should have received a copy of the GNU General Public License     */
/*     along with foma.  If not, see <http://www.gnu.org/licenses/>.         */
#define YY_NO_INPUT 1
#line 22 "cmatrix.l"

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "foma.h"

extern int cmatrixlex();
static struct fsm *mnet;
static int currcost;
static char *instring;

void my_cmatrixparse(struct fsm *net, char *my_string) {
   				       
   YY_BUFFER_STATE my_string_buffer;

   currcost = 1;
   my_string_buffer = cmatrix_scan_string(my_string);
   mnet = net;
   cmatrix_init(mnet);
   cmatrixlex();
   cmatrix_delete_buffer(my_string_buffer);
}


#line 737 "lex.cmatrix.c"

#define INITIAL 0
#define SUB 1
#define DEL 2
#define INS 3
#define COST 4
#define OUTSTRING 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int cmatrixlex_destroy (void );

int cmatrixget_debug (void );

void cmatrixset_debug (int debug_flag  );

YY_EXTRA_TYPE cmatrixget_extra (void );

void cmatrixset_extra (YY_EXTRA_TYPE user_defined  );

FILE *cmatrixget_in (void );

void cmatrixset_in  (FILE * in_str  );

FILE *cmatrixget_out (void );

void cmatrixset_out  (FILE * out_str  );

int cmatrixget_leng (void );

char *cmatrixget_text (void );

int cmatrixget_lineno (void );

void cmatrixset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int cmatrixwrap (void );
#else
extern int cmatrixwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( cmatrixtext, cmatrixleng, 1, cmatrixout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( cmatrixin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( cmatrixin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, cmatrixin))==0 && ferror(cmatrixin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(cmatrixin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int cmatrixlex (void);

#define YY_DECL int cmatrixlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after cmatrixtext and cmatrixleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( cmatrixleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(cmatrixtext[cmatrixleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 53 "cmatrix.l"


#line 933 "lex.cmatrix.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)cmatrixalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in cmatrixlex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! cmatrixin )
			cmatrixin = stdin;

		if ( ! cmatrixout )
			cmatrixout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			cmatrixensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				cmatrix_create_buffer(cmatrixin,YY_BUF_SIZE );
		}

		cmatrix_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of cmatrixtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 116 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 678 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 55 "cmatrix.l"
{ BEGIN(SUB);  }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 56 "cmatrix.l"
{ BEGIN(DEL);  }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 57 "cmatrix.l"
{ BEGIN(INS);  }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 58 "cmatrix.l"
{ BEGIN(COST); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 59 "cmatrix.l"
{ }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 61 "cmatrix.l"
{
  cmatrix_set_cost(mnet, NULL, cmatrixtext+1, currcost);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 65 "cmatrix.l"
{
  *(cmatrixtext+strlen(cmatrixtext)-1) = '\0';
  cmatrix_set_cost(mnet, cmatrixtext, NULL, currcost);
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 70 "cmatrix.l"
{
  instring = xxstrndup(cmatrixtext, strlen(cmatrixtext)-1);
  BEGIN(OUTSTRING);

}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 75 "cmatrix.l"
{
  cmatrix_set_cost(mnet, instring, cmatrixtext, currcost);
  BEGIN(INITIAL);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 80 "cmatrix.l"
{
  cmatrix_default_substitute(mnet, atoi(cmatrixtext));
  BEGIN(INITIAL);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 84 "cmatrix.l"
{
  cmatrix_default_delete(mnet, atoi(cmatrixtext));
  BEGIN(INITIAL);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 88 "cmatrix.l"
{
  cmatrix_default_insert(mnet, atoi(cmatrixtext));
  BEGIN(INITIAL);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 93 "cmatrix.l"
{
  currcost = atoi(cmatrixtext);
  BEGIN(INITIAL);
}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 98 "cmatrix.l"
{ }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 99 "cmatrix.l"
ECHO;
	YY_BREAK
#line 1150 "lex.cmatrix.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(SUB):
			case YY_STATE_EOF(DEL):
			case YY_STATE_EOF(INS):
			case YY_STATE_EOF(COST):
			case YY_STATE_EOF(OUTSTRING):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed cmatrixin at a new source and called
			 * cmatrixlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = cmatrixin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( cmatrixwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * cmatrixtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of cmatrixlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			cmatrixrestart(cmatrixin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) cmatrixrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 24);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 116 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 24;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 116 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 115);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					cmatrixrestart(cmatrixin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( cmatrixwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve cmatrixtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 *
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void cmatrixrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        cmatrixensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            cmatrix_create_buffer(cmatrixin,YY_BUF_SIZE );
	}

	cmatrix_init_buffer(YY_CURRENT_BUFFER,input_file );
	cmatrix_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 *
 */
    void cmatrix_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		cmatrixpop_buffer_state();
	 *		cmatrixpush_buffer_state(new_buffer);
     */
	cmatrixensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	cmatrix_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (cmatrixwrap()) processing, but the only time this flag
	 * is looked at is after cmatrixwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void cmatrix_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	cmatrixin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 *
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE cmatrix_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) cmatrixalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in cmatrix_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) cmatrixalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in cmatrix_create_buffer()" );

	b->yy_is_our_buffer = 1;

	cmatrix_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with cmatrix_create_buffer()
 *
 */
    void cmatrix_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		cmatrixfree((void *) b->yy_ch_buf  );

	cmatrixfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a cmatrixrestart() or at EOF.
 */
    static void cmatrix_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	cmatrix_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then cmatrix_init_buffer was _probably_
     * called from cmatrixrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 *
 */
    void cmatrix_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		cmatrix_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *
 */
void cmatrixpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	cmatrixensure_buffer_stack();

	/* This block is copied from cmatrix_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from cmatrix_switch_to_buffer. */
	cmatrix_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *
 */
void cmatrixpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	cmatrix_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		cmatrix_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void cmatrixensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmatrixalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in cmatrixensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmatrixrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in cmatrixensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE cmatrix_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) cmatrixalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in cmatrix_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	cmatrix_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to cmatrixlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 *
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       cmatrix_scan_bytes() instead.
 */
YY_BUFFER_STATE cmatrix_scan_string (yyconst char * yystr )
{
    
	return cmatrix_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to cmatrixlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 *
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE cmatrix_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) cmatrixalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in cmatrix_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = cmatrix_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in cmatrix_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up cmatrixtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		cmatrixtext[cmatrixleng] = (yy_hold_char); \
		(yy_c_buf_p) = cmatrixtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		cmatrixleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 *
 */
int cmatrixget_lineno  (void)
{
        
    return cmatrixlineno;
}

/** Get the input stream.
 *
 */
FILE *cmatrixget_in  (void)
{
        return cmatrixin;
}

/** Get the output stream.
 *
 */
FILE *cmatrixget_out  (void)
{
        return cmatrixout;
}

/** Get the length of the current token.
 *
 */
int cmatrixget_leng  (void)
{
        return cmatrixleng;
}

/** Get the current token.
 *
 */

char *cmatrixget_text  (void)
{
        return cmatrixtext;
}

/** Set the current line number.
 * @param line_number
 *
 */
void cmatrixset_lineno (int  line_number )
{
    
    cmatrixlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 *
 * @see cmatrix_switch_to_buffer
 */
void cmatrixset_in (FILE *  in_str )
{
        cmatrixin = in_str ;
}

void cmatrixset_out (FILE *  out_str )
{
        cmatrixout = out_str ;
}

int cmatrixget_debug  (void)
{
        return cmatrix_flex_debug;
}

void cmatrixset_debug (int  bdebug )
{
        cmatrix_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from cmatrixlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    cmatrixin = stdin;
    cmatrixout = stdout;
#else
    cmatrixin = (FILE *) 0;
    cmatrixout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * cmatrixlex_init()
     */
    return 0;
}

/* cmatrixlex_destroy is for both reentrant and non-reentrant scanners. */
int cmatrixlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		cmatrix_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		cmatrixpop_buffer_state();
	}

	/* Destroy the stack itself. */
	cmatrixfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    cmatrixfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * cmatrixlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *cmatrixalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *cmatrixrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void cmatrixfree (void * ptr )
{
	free( (char *) ptr );	/* see cmatrixrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 99 "cmatrix.l"
